@@ -56,7 +56,7 @@ class ApplePayApi(BaseApi):
         # Prepare headers
         _headers = {
             'accept': 'application/json',
-            'content-type': 'application/json; charset=utf-8'
+            'Content-Type': 'application/json'
         }
 
         # Prepare and execute request
